import { NgbDate, NgbDatepicker, NgbDropdown } from '@ng-bootstrap/ng-bootstrap';
import moment from 'moment-mini';
import { DateRange } from '../enums/date-range';
import { DefaultDateRanges } from '../models/default-date-ranges';
import * as i0 from "@angular/core";
/**
 * A utility class for the date range picker component
 */
export declare class DateRangePickerUtils {
    constructor();
    /**
     * Returns the start and end dates of a given date range key as moment objects.
     *
     * @param dateRangeKey The string value representing the selected date range key.
     *
     * @returns An array of two moment.Moment objects representing the start and end dates of the selected date range.
     */
    getDateRangeAsMoments(dateRangeKey: string): [moment.Moment, moment.Moment];
    /**
     * Returns the corresponding DateRange enum value based on a given string key.
     *
     * @param rangeKey The string value representing the selected date range key.
     *
     * @returns The corresponding DateRange enum value if found, or DateRange.Last28Days as a default.
     */
    getDateRangeFromKey(rangeKey: string): DateRange;
    /**
     * Returns a formatted label for the selected date range, based on the provided start and end moment objects.
     *
     * @param fromMoment The moment object representing the start date of the selected date range.
     * @param toMoment The moment object representing the end date of the selected date range.
     *
     * @returns A formatted string label for the selected date range.
     */
    getSelectedRangeDateLabel(fromMoment: moment.Moment, toMoment: moment.Moment): string;
    /**
     * Focuses on a specific date in a NgbDatepicker component.
     *
     * @param dateRangerPicker The NgbDatepicker component to focus on.
     * @param fromDate The NgbDate object representing the date to focus on.
     *
     * @returns None.
     */
    focusDateInPicker(dateRangerPicker: NgbDatepicker | undefined, fromDate: NgbDate): void;
    /**
     * Converts a moment object to a NgbDate object.
     *
     * @param momentObj The moment object to convert.
     *
     * @returns The corresponding NgbDate object.
     */
    convertToNgbDate(momentObj: moment.Moment): NgbDate;
    /**
     * Closes the NgbDropdown component if it is open.
     *
     * @param dropdown The NgbDropdown component to close.
     *
     * @returns None.
     */
    closeDropDown(dropdown: NgbDropdown | undefined): void;
    /**
     * Returns an object containing default date ranges for the date range picker.
     *
     * @returns An object containing default date ranges, with the keys being the DateRange enum values and the values being arrays of start and end dates as strings.
     */
    getDefaultDateRanges(): DefaultDateRanges;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateRangePickerUtils, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DateRangePickerUtils>;
}
